@@ -137,7 +137,7 @@ use warnings;
 
 use base qw{ Astro::Coord::ECI::TLE };
 
-our $VERSION = '0.105';
+our $VERSION = '0.106';
 
 use Astro::Coord::ECI::Utils 0.091 qw{:all};
 use Carp;
@@ -1681,7 +1681,7 @@ sub _set_operational_status {
 # All Iridium Classic satellites.
 #
 # Generated by Astro::SpaceTrack tools/all_iridium_classic -tle -indent=0
-# on Sun Sep  2 23:31:25 2018 GMT
+# on Tue Sep 11 12:52:04 2018 GMT
 
 __PACKAGE__->status( clear => 'iridium' );
 __PACKAGE__->status( add => 24792, iridium => 'D', 'Iridium 8', 'Decayed 2017-11-24' );
@@ -1733,9 +1733,9 @@ __PACKAGE__->status( add => 25106, iridium => 'D', 'Iridium 47', 'Decayed 2018-0
 __PACKAGE__->status( add => 25107, iridium => 'D', 'Iridium 48', 'Decayed 2001-05-05' );
 __PACKAGE__->status( add => 25108, iridium => 'D', 'Iridium 49', 'Decayed 2018-02-13' );
 __PACKAGE__->status( add => 25169, iridium => '+', 'Iridium 52', '' );
-__PACKAGE__->status( add => 25170, iridium => 'S', 'Iridium 56', '' );
+__PACKAGE__->status( add => 25170, iridium => '-', 'Iridium 56', 'Tumbling' );
 __PACKAGE__->status( add => 25171, iridium => '+', 'Iridium 54', '' );
-__PACKAGE__->status( add => 25172, iridium => 'S', 'Iridium 50', '' );
+__PACKAGE__->status( add => 25172, iridium => '-', 'Iridium 50', 'Tumbling' );
 __PACKAGE__->status( add => 25173, iridium => '+', 'Iridium 53', '' );
 __PACKAGE__->status( add => 25262, iridium => '-', 'Iridium 51', 'Tumbling' );
 __PACKAGE__->status( add => 25263, iridium => 'S', 'Iridium 61', '' );
@@ -1766,9 +1766,9 @@ __PACKAGE__->status( add => 25469, iridium => 'D', 'Iridium 80', 'Decayed 2018-0
 __PACKAGE__->status( add => 25470, iridium => 'D', 'Iridium 79', 'Decayed 2000-11-29' );
 __PACKAGE__->status( add => 25471, iridium => 'D', 'Iridium 77', 'Decayed 2017-09-22' );
 __PACKAGE__->status( add => 25527, iridium => '-', 'Iridium 2', 'Tumbling' );
-__PACKAGE__->status( add => 25528, iridium => 'S', 'Iridium 86', '' );
+__PACKAGE__->status( add => 25528, iridium => '-', 'Iridium 86', 'Tumbling' );
 __PACKAGE__->status( add => 25529, iridium => 'D', 'Iridium 85', 'Decayed 2000-12-30' );
-__PACKAGE__->status( add => 25530, iridium => '+', 'Iridium 84', '' );
+__PACKAGE__->status( add => 25530, iridium => 'S', 'Iridium 84', '' );
 __PACKAGE__->status( add => 25531, iridium => '+', 'Iridium 83', '' );
 __PACKAGE__->status( add => 25577, iridium => 'S', 'Iridium 20', '' );
 __PACKAGE__->status( add => 25578, iridium => 'S', 'Iridium 11', '' );
@@ -1783,9 +1783,9 @@ __PACKAGE__->status( add => 27450, iridium => 'S', 'Iridium 97', '' );
 __PACKAGE__->status( add => 27451, iridium => 'D', 'Iridium 98', 'Decayed 2018-08-24' );
 
 # Summary:
-# Operational [+]: 14
-#       Spare [S]: 14
-#    Tumbling [-]: 34
+# Operational [+]: 13
+#       Spare [S]: 12
+#    Tumbling [-]: 37
 #     Decayed [D]: 35
 
 1;
